===============================
Spree API Client in Python
===============================


.. image:: https://img.shields.io/pypi/v/spree.svg
        :target: https://pypi.python.org/pypi/spree

.. image:: https://img.shields.io/travis/audreyr/spree.svg
        :target: https://travis-ci.org/audreyr/spree

.. image:: https://readthedocs.org/projects/spree/badge/?version=latest
        :target: https://spree.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/audreyr/cookiecutter-django/shield.svg
     :target: https://pyup.io/repos/github/audreyr/spree/
     :alt: Updates


Spree python api client


* Free software: BSD license
* Documentation: https://spree.readthedocs.io.


Features
--------

* TODO
